@@ -57,7 +57,6 @@ import java.util.LinkedHashSet;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.Executors;
-import java.util.concurrent.RejectedExecutionHandler;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
@@ -91,13 +90,12 @@ public class AsyncExecutor implements ICounter {
      * @author <a href="mailto:kai.ahrens@open-xchange.com">Kai Ahrens</a>
      * @since v7.8.0
      */
-    protected class AsyncIdentifier {
+    protected static class AsyncIdentifier {
 
         protected AsyncIdentifier(@NonNull final String asyncHash) {
             super();
 
             m_asyncHash = asyncHash;
-            m_startTimeMillis = System.currentTimeMillis();
         }
 
         /* (non-Javadoc)
@@ -146,15 +144,15 @@ public class AsyncExecutor implements ICounter {
         /**
          * @return
          */
-        protected long getStartTimeMillis() {
-            return m_startTimeMillis;
+        protected long getTimestampMillis() {
+            return m_timestampMillis;
         }
 
         // - Members -----------------------------------------------------------
 
-        private String m_asyncHash = null;
+        final private String m_asyncHash;
 
-        private long m_startTimeMillis = 0;
+        final private long m_timestampMillis = System.currentTimeMillis();
     }
 
     /**
@@ -299,17 +297,16 @@ public class AsyncExecutor implements ICounter {
                 final StringBuilder fileHashBuilder = DocumentConverterManager.getFileHashBuilder(inputFile, locale);
 
                 if (null != fileHashBuilder) {
-                    asyncHashBuilder.append(m_jobType).append('-').
-                        append(DocumentConverterManager.getFileHashBuilder(inputFile, locale).toString());
+                    asyncHashBuilder.append(m_jobType).append('-').append(DocumentConverterManager.getFileHashBuilder(inputFile, locale).toString());
                 } else {
                     asyncHashBuilder = null;
                 }
             }
 
-             if (null != asyncHashBuilder) {
-                 asyncHashBuilder.append(((JobPriority) m_jobProperties.get(Properties.PROP_PRIORITY)).toString());
-                 ret = new AsyncIdentifier(asyncHashBuilder.toString());
-             }
+            if (null != asyncHashBuilder) {
+                asyncHashBuilder.append(((JobPriority) m_jobProperties.get(Properties.PROP_PRIORITY)).toString());
+                ret = new AsyncIdentifier(asyncHashBuilder.toString());
+            }
 
             return ret;
         }
@@ -334,45 +331,30 @@ public class AsyncExecutor implements ICounter {
             m_manager = manager;
             m_requestExecutor = new ThreadPoolExecutor(maxThreadCount, maxThreadCount, 0, TimeUnit.MILLISECONDS, m_requestQueue);
 
-            m_requestExecutor.setRejectedExecutionHandler(new RejectedExecutionHandler() {
-
-                @Override
-                public void rejectedExecution(Runnable runnable, ThreadPoolExecutor executor) {
-                    if (null != runnable) {
-                        ((AsyncRunnable) runnable).clear();
-                    }
+            // ensure, that entry is cleaned up (e.g. remove tmp. files) if execution is rejected
+            m_requestExecutor.setRejectedExecutionHandler((runnable, executor) -> {
+                if (null != runnable) {
+                    ((AsyncRunnable) runnable).clear();
                 }
             });
 
             // initialize timer to clean up run set
-            final Runnable cleanupRunnable = new Runnable() {
+            m_timerExecutor.scheduleAtFixedRate(() -> {
+                final long curTimeMillis = System.currentTimeMillis();
 
-                @Override
-                public void run() {
-                    final long curTimeMillis = System.currentTimeMillis();
-
-                    synchronized (m_runSet) {
-                        final Iterator<AsyncIdentifier> asyncIdIter = m_runSet.iterator();
-
-                        while (asyncIdIter.hasNext()) {
-                            final AsyncIdentifier curAsyncId = asyncIdIter.next();
-
-                            if (null != curAsyncId) {
-                                if ((curTimeMillis - curAsyncId.getStartTimeMillis()) > CLEANUP_TIMEOUT_MILLIS) {
-                                    asyncIdIter.remove();
-                                } else {
-                                    // since the items are ordered by time, we
-                                    // can stop the search when the first item
-                                    // did not reach its timeout
-                                    break;
-                                }
-                            }
+                synchronized (m_runSet) {
+                    for (final Iterator<AsyncIdentifier> asyncIdIter = m_runSet.iterator(); asyncIdIter.hasNext();) {
+                        if ((curTimeMillis - asyncIdIter.next().getTimestampMillis()) > CLEANUP_TIMEOUT_MILLIS) {
+                            asyncIdIter.remove();
+                        } else {
+                            // since the items are ordered by time, we
+                            // can stop the search when the first item
+                            // did not reach its timeout
+                            break;
                         }
                     }
                 }
-            };
-
-            m_timerExecutor.scheduleAtFixedRate(cleanupRunnable, CLEANUP_TIMEOUT_MILLIS, CLEANUP_TIMEOUT_MILLIS, TimeUnit.MILLISECONDS);
+            }, CLEANUP_TIMEOUT_MILLIS, CLEANUP_TIMEOUT_MILLIS, TimeUnit.MILLISECONDS);
         }
     }
 
@@ -491,6 +473,10 @@ public class AsyncExecutor implements ICounter {
         boolean ret = true;
 
         synchronized (m_runSet) {
+            // if entry with same AsyncId is already contained
+            // in run set => remove old entry and put new entry
+            // with up to date timestamp at end of time based
+            // ordered LinkedHashSet
             if (m_runSet.remove(asyncId)) {
                 ret = false;
             }
