@@ -99,6 +99,15 @@ public class DocumentConverterManager {
 
     final private static String UNKNOWN_FILENAME = "n/a";
 
+    final private static String[] BASH_SEARCH_PATHES = {
+        "/bin/bash",
+        "/sbin/bash",
+        "/usr/bin/bash",
+        "/usr/local/bin/bash",
+        "/usr/local/sbin/bash"
+    };
+
+
     /**
      * Initializes a new {@link DocumentConverterManager}.
      */
@@ -374,6 +383,110 @@ public class DocumentConverterManager {
         return filename;
     }
 
+    /**
+     * @param rawBashCommandLine The raw bash line to append commands to the last command element
+     * @param commandLine The command parts to append to the last bash command element
+     * @return Returns the cloned bash command line array with appended command parts to the last command element
+     */
+    public static  String[] getCommandLine(final String[] rawBashCommandLine, final String[] commandLine) {
+        final String[] cmdLine = (null != rawBashCommandLine) ? rawBashCommandLine.clone() : new String[] { "" };
+        final int cmdLineLastElementPos = cmdLine.length - 1;
+        final StringBuilder pdfExtractorCmdLine = new StringBuilder(512).
+            append(cmdLine[cmdLineLastElementPos]);
+
+        if (null != commandLine) {
+            for (final String curCommandLinePart : commandLine) {
+                pdfExtractorCmdLine.append(' ').append(curCommandLinePart);
+            }
+        }
+
+        // replace last command element with updated one
+        cmdLine[cmdLineLastElementPos] = pdfExtractorCmdLine.toString();
+
+        return cmdLine;
+    }
+
+    /**
+     * @param maxVMemMB
+     * @return The bash process command array, containing possible
+     *  max VMem settings within the last element.
+     *  The last element needs to be appended with the
+     *  real command to be be finally usable
+     */
+    public static String[] getMaxVMemBashCommandLine(final long maxVMemMB) {
+        String[] ret = null;
+
+        if (maxVMemMB > 0) {
+            final String uLimitVMemKbStr = Long.toString(1024L * maxVMemMB);
+
+            for (String curBashPath : BASH_SEARCH_PATHES) {
+                if (new File(curBashPath).canExecute()) {
+                    ret = new String[] { curBashPath, "-c", new StringBuilder(256).
+                        append("ulimit -v ").append(uLimitVMemKbStr).append("; ").
+                        append("ulimit -m ").append(uLimitVMemKbStr).append("; ").toString() };
+
+                    break;
+                }
+            }
+        }
+
+        if (null == ret) {
+            ret = new String[] { "" };
+
+            final StringBuilder searchPathesBuilder = new StringBuilder(512);
+
+            for (String curBashPath : BASH_SEARCH_PATHES) {
+                if (searchPathesBuilder.length() > 0) {
+                    searchPathesBuilder.append(':');
+                }
+
+                searchPathesBuilder.append(curBashPath);
+            }
+
+            logError("DC cannot execute PDFTool due to missing Bash executable. Search path: " + searchPathesBuilder.toString());
+        }
+
+        return ret;
+
+    }
+
+    /**
+     * Method impl. is copied from Process#waitFor(long timeout, TimeUnit unit) method
+     * with the difference that this method returns the exit code of the process in case
+     * of termination in time or -1 in case of timeout or invalid process.
+     * This method works on milliseconds only as well.
+     * @param process The process to wait for.
+     * @param timeoutMillis The milliseconds to wait for the process before -1 is returned.
+     * @return The exit code of the process or -1 if process has reached its timeout or process is <code>null</code>.
+     */
+    public static int waitForProcess(final Process process, final long timeoutMillis) {
+        if (null != process) {
+            final long startTimeMillis = System.currentTimeMillis();
+            long remMillis = timeoutMillis;
+
+            Thread.yield();
+
+            do {
+                try {
+                    // if process has not yet terminated, an IllegalThreadStateException is thrown
+                    final int exitValue = process.exitValue();
+                    return exitValue;
+                } catch(@SuppressWarnings("unused") IllegalThreadStateException e) {
+                    if (remMillis > 0) {
+                        try {
+                            Thread.sleep(Math.min(remMillis + 1, 50));
+                        } catch (@SuppressWarnings("unused") InterruptedException e1) {
+                            break;
+                        }
+                    }
+                }
+
+                remMillis = timeoutMillis - (System.currentTimeMillis() - startTimeMillis);
+            } while (remMillis > 0);
+        }
+
+        return -1;
+    }
 
     // - Logging ---------------------------------------------------------------
 
