@@ -74,7 +74,7 @@ import org.apache.commons.io.FileUtils;
 public class FileIdManager {
 
     // TODO (KA): set to 5 minutes default for release
-    public static final long AUTOREMOVE_TIMEOUT_MILLIS_DEFAULT = 5 * 60 * 1000;
+    public static final long AUTOREMOVE_TIMEOUT_MILLIS_DEFAULT = 5 * 60 * 1000L;
 
     /**
      * {@link FileIdData}
@@ -304,7 +304,7 @@ public class FileIdManager {
                 m_deleteExecutorService.shutdown();
                 m_deleteExecutorService.awaitTermination(60, TimeUnit.SECONDS);
             } catch (InterruptedException e) {
-                DocumentConverterManager.logError("DC client FildIdManager cleanup got interrupted during shutdown");
+                // ok
             }
 
             if (trace) {
@@ -404,6 +404,8 @@ public class FileIdManager {
         m_deleteExecutorService.execute(() -> {
             FileIdData fileIdDataToUnlock = null;
 
+            // !!! Closing and resource removal of FileIdData is done by using try-with-resource call in this case !!!
+            //
             // lock FileIdData in run method and close it to cleanup
             // entry (temp. file) and to remove from managed map of FileIdData;
             // save current FileIdData in temp. variable to be able to
@@ -502,6 +504,8 @@ public class FileIdManager {
 
     // - Static Members --------------------------------------------------------
 
+    final private static String DC_FILEIDMANAGER_TIMER_NAME = "DC FileIdManager timer";
+
     private static FileIdManager fileIdManager = null;
 
     // - Members ---------------------------------------------------------------
@@ -514,7 +518,7 @@ public class FileIdManager {
 
     final protected Map<String, FileIdData> m_fileIdMap = new HashMap<>();
 
-    final protected Timer m_autoCleanupCheckTimer = new Timer(true);
+    final protected Timer m_autoCleanupCheckTimer = new Timer(DC_FILEIDMANAGER_TIMER_NAME, true);
 
     final protected ExecutorService m_deleteExecutorService = Executors.newSingleThreadExecutor();
 }
