@@ -71,12 +71,6 @@ public class Properties {
 
     // -------------------------------------------------------------------------
 
-    static final public int JOB_MAJOR_VERSION = 1;
-
-    static final public int JOB_MINOR_VERSION = 1;
-
-    // -------------------------------------------------------------------------
-
     static final public String CACHE_PROPERTIES_FILENAME = "properties"; // String
 
     static final public String CACHE_RESULT_FILENAME = "result"; // String
@@ -145,6 +139,8 @@ public class Properties {
 
     static final public String PROP_CACHE_ONLY = "CacheOnly"; // Boolean
 
+    static final public String PROP_NO_CACHE = "NoCache"; // Boolean
+
     static final public String PROP_AUTOSCALE = "AutoScale"; // Boolean
 
     static final public String PROP_HIDE_CHANGES = "HideChanges"; // Boolean
